# ifndef yyMakeArguments
# define yyMakeArguments

# if defined __STDC__ | defined __cplusplus
# define ARGS(parameters)	parameters
# else
# define ARGS(parameters)	()
# endif

# ifndef rbool
# define rbool char
# endif

# include "Tree.h"
# include "Definitions.h"

/* line 28 "MakeArguments.puma" */


#include "VarDescriptor.h"



extern void (* MakeArguments_Exit) ARGS ((void));

extern void MakeArguments ARGS ((tTree t));

extern void BeginMakeArguments ARGS ((void));
extern void CloseMakeArguments ARGS ((void));

# endif
